==> haskell-bitarray-0.0.1.1-22-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-bitarray.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 bitarray
version:              0.0.1.1
visibility:           public
id:                   bitarray-0.0.1.1-87mIs3jrS4vLQFE8A1s1CY
key:                  bitarray-0.0.1.1-87mIs3jrS4vLQFE8A1s1CY
license:              BSD-3-Clause
copyright:            (c) 2009 Balazs Komuves
maintainer:           bkomuves (plus) hackage (at) gmail (dot) com
author:               Balazs Komuves
stability:            Experimental
homepage:             http://code.haskell.org/~bkomuves/
synopsis:             Mutable and immutable bit arrays
description:          Mutable and immutable bit arrays.
category:             Data
abi:                  75ed30043cd81f92d3f315e83804a061
exposed:              True
exposed-modules:      Data.BitArray Data.BitArray.IO Data.BitArray.ST
hidden-modules:       Data.BitArray.Immutable
import-dirs:          /usr/lib/ghc-9.0.1/site-local/bitarray-0.0.1.1
library-dirs:         /usr/lib/ghc-9.0.1/site-local/bitarray-0.0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/bitarray-0.0.1.1
hs-libraries:         HSbitarray-0.0.1.1-87mIs3jrS4vLQFE8A1s1CY
depends:              array-0.5.4.0 base-4.15.0.0
haddock-interfaces:   /usr/share/doc/haskell-bitarray/html/bitarray.haddock
haddock-html:         /usr/share/doc/haskell-bitarray/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-bitarray-0.0.1.1-23-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-bitarray.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 bitarray
version:              0.0.1.1
visibility:           public
id:                   bitarray-0.0.1.1-LEJJ33hSxtD71D0jFIIA6I
key:                  bitarray-0.0.1.1-LEJJ33hSxtD71D0jFIIA6I
license:              BSD-3-Clause
copyright:            (c) 2009 Balazs Komuves
maintainer:           bkomuves (plus) hackage (at) gmail (dot) com
author:               Balazs Komuves
stability:            Experimental
homepage:             http://code.haskell.org/~bkomuves/
synopsis:             Mutable and immutable bit arrays
description:          Mutable and immutable bit arrays.
category:             Data
abi:                  83fffe49f8d5c671c6b0da1bca491790
exposed:              True
exposed-modules:      Data.BitArray Data.BitArray.IO Data.BitArray.ST
hidden-modules:       Data.BitArray.Immutable
import-dirs:          /usr/lib/ghc-9.0.2/site-local/bitarray-0.0.1.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/bitarray-0.0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/bitarray-0.0.1.1
hs-libraries:         HSbitarray-0.0.1.1-LEJJ33hSxtD71D0jFIIA6I
depends:              array-0.5.4.0 base-4.15.1.0
haddock-interfaces:   /usr/share/doc/haskell-bitarray/html/bitarray.haddock
haddock-html:         /usr/share/doc/haskell-bitarray/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
